gmail v0.1.6 Gmail.History

Lists the history of all changes to the given mailbox.

Summary

Functions

Lists the history of all changes to the given mailbox. History results are returned in chronological order (increasing historyId)

Functions

list(user_id, params)

Specs

list(String.t, map) :: {atom, String.t, String.t}

Lists the history of all changes to the given mailbox. History results are returned in chronological order (increasing historyId).