gmail v0.1.6 Gmail.User
Represents a user’s mailbox, holding it’s config and tokens.
Summary
Functions
Gets a draft from the specified user’s mailbox
Sends a draft from the specified user’s mailbox
Lists the drafts in the specified user’s mailbox
Lists the hsitory for the specified user’s mailbox
Gets a label from the specified user’s mailbox
Patches a label in the specified user’s mailbox
Lists all labels in the specified user’s mailbox
Gets a message from the specified user’s mailbox
Removes the specified message from the trash in the user’s mailbox
Lists the messages in the specified user’s mailbox
Searches for messages or threads in the specified user’s mailbox
Starts the process for the specified user
Stops the process for the specified user
Gets a thread from the specified user’s mailbox
Removes the specified thread from the trash in the user’s mailbox
Lists the threads in the specified user’s mailbox
Functions
Removes the specified message from the trash in the user’s mailbox.
Specs
messages(String.t, map) :: {atom, [Gmail.Message.t]}
Lists the messages in the specified user’s mailbox.
Searches for messages or threads in the specified user’s mailbox.
Removes the specified thread from the trash in the user’s mailbox.